EndpointLegacyUser class Endpoint
Proxy endpoint for legacy user profile operations (image, name changes).
- Inheritance
-
- Object
- EndpointRef
- EndpointLegacyUser
Constructors
- EndpointLegacyUser(EndpointCaller caller)
Properties
- caller → EndpointCaller
-
Holds a reference to the caller class.
finalinherited
- client ↔ ServerpodClientShared
-
Reference to the client.
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of the endpoint this reference is connected to.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
SerializableModel> -
Stream of messages sent from an endpoint that supports streaming.
no setterinherited
Methods
-
changeFullName(
String fullName) → Future< bool> - Changes the user's full name.
-
changeUserName(
String userName) → Future< bool> - Changes the user's display name.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeUserImage(
) → Future< bool> - Removes the user's profile image.
-
resetStream(
) → void -
Resets web socket stream, so it's possible to re-listen to endpoint
streams.
inherited
-
sendStreamMessage(
SerializableModel message) → Future< void> -
Sends a message to the endpoint's stream.
inherited
-
setUserImage(
ByteData image) → Future< bool> - Sets the user's profile image from binary data.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited